@@ -5,20 +5,18 @@
   Copyright (C) 2001-2002 Andreas Gruenbacher <a.gruenbacher@bestbits.at>
   Copyright (C) 2001-2002 Silicon Graphics, Inc.  All Rights Reserved.
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at
-  your option) any later version.
+  This program is free software: you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 2 of the License, or
+  (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-  USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <limits.h>
@@ -66,14 +64,17 @@ int base64_digit(char c);
 
 const char *strerror_ea(int err)
 {
+#ifdef __linux__
+	/* The Linux kernel does not define ENOATTR, but maps it to ENODATA. */
 	if (err == ENODATA)
 		return _("No such attribute");
+#endif
 	return strerror(err);
 }
 
-static const char *xquote(const char *str)
+static const char *xquote(const char *str, const char *quote_chars)
 {
-	const char *q = quote(str);
+	const char *q = quote(str, quote_chars);
 	if (q == NULL) {
 		fprintf(stderr, "%s: %s\n", progname, strerror(errno));
 		exit(1);
@@ -275,7 +276,7 @@ int do_set(const char *path, const char *name, const char *value)
 
 	if (error < 0) {
 		fprintf(stderr, "%s: %s: %s\n",
-			progname, xquote(path), strerror_ea(errno));
+			progname, xquote(path, "\n\r"), strerror_ea(errno));
 		had_errors++;
 		return 1;
 	}
